@@ -153,6 +153,42 @@ class CommitComment(github.GithubObject.CompletableGithubObject):
         )
         self._useAttributes(data)
 
+    def get_reactions(self):
+        """
+        :calls: `GET /repos/:owner/:repo/comments/:id/reactions
+                <https://developer.github.com/v3/reactions/#list-reactions-for-a-commit-comment>`
+        :return: :class: :class:`github.PaginatedList.PaginatedList` of :class:`github.Reaction.Reaction`
+        """
+        return github.PaginatedList.PaginatedList(
+            github.Reaction.Reaction,
+            self._requester,
+            self.url + "/reactions",
+            None,
+            headers={'Accept': 'application/vnd.github.squirrel-girl-preview'}
+        )
+
+    def create_reaction(self, reaction_type):
+        """
+        :calls: `POST /repos/:owner/:repo/comments/:id/reactions
+                <https://developer.github.com/v3/reactions/#create-reaction-for-a-commit-comment>`_
+        :param reaction_type: string
+        :rtype: :class:`github.Reaction.Reaction`
+        """
+        assert isinstance(reaction_type, str), "reaction type should be a string"
+        assert reaction_type in ["+1", "-1", "laugh", "confused", "heart", "hooray"], \
+            "Invalid reaction type (https://developer.github.com/v3/reactions/#reaction-types)"
+
+        post_parameters = {
+            "content": reaction_type,
+        }
+        headers, data = self._requester.requestJsonAndCheck(
+            "POST",
+            self.url + "/reactions",
+            input=post_parameters,
+            headers={'Accept': 'application/vnd.github.squirrel-girl-preview'}
+        )
+        return github.Reaction.Reaction(self._requester, headers, data, completed=True)
+
     def _initAttributes(self):
         self._body = github.GithubObject.NotSet
         self._commit_id = github.GithubObject.NotSet
