@@ -25,10 +25,7 @@
 from . import Framework
 import github
 
-if Framework.atLeastPython26:
-    from io import BytesIO as IO
-else:
-    from io import StringIO as IO
+from io import BytesIO as IO
 
 
 class Persistence(Framework.TestCase):
